@@ -1,5 +1,10 @@
+"""
+Matchers that match close to anything
+"""
+
 from typing import Optional
 from .__jestspectation_base import JestspectationBase
+from .__util import get_type_name, get_object_type_name
 
 
 class Any(JestspectationBase):
@@ -17,7 +22,7 @@ class Any(JestspectationBase):
         self.__match_type = match_type
 
     def __repr__(self) -> str:
-        return f"Any({self.__match_type.__name__})"
+        return f"Any({get_type_name(self.__match_type)})"
 
     def __eq__(self, other: object) -> bool:
         return isinstance(other, self.__match_type)
@@ -26,8 +31,9 @@ class Any(JestspectationBase):
         if self == other:
             return None
         return [
-            f'Expecting {self}',
-            f'   Received {other.__class__.__name__} ({repr(other)})',
+            'Type mismatch',
+            f'Expected any object of type {get_type_name(self.__match_type)}',
+            f'Received {repr(other)} ({get_object_type_name(other)})',
         ]
 
 
@@ -47,5 +53,5 @@ class Anything(JestspectationBase):
     def __eq__(self, other: object) -> bool:
         return True
 
-    def get_diff(self, other) -> Optional[list[str]]:
+    def get_diff(self, other: object) -> Optional[list[str]]:
         return None
