@@ -1,7 +1,12 @@
+"""
+Matchers for specific container types
+"""
+
 from abc import abstractmethod
 from collections.abc import Iterable
 from typing import Optional, TypeGuard
 from .__jestspectation_base import JestspectationBase
+from .__util import get_object_type_name
 
 
 class JestspectationContainer(JestspectationBase):
@@ -53,12 +58,15 @@ class JestspectationContainer(JestspectationBase):
             return None
         if not self.__is_allowed_type(other):
             return [
-                f"Expected {self}, but received a {type(other).__name__}"
+                "Type mismatch",
+                f"Expected {self}",
+                f"Received object of type {get_object_type_name(other)}"
             ]
         misses = self.__get_misses(other)
         return [
-            f"Expected {repr(other)} to be {self}, but was missing",
-        ] + [f"   {repr(i)}" for i in misses]
+            "Missing properties",
+            f"Expected a {self}, but was missing properties",
+        ] + [f"- {repr(i)}" for i in misses]
 
     def __eq__(self, other: object) -> bool:
         if not self.__is_allowed_type(other):
