@@ -12,13 +12,13 @@ class JestspectationBase:
     Base class of types used in Jestspectation
     """
     @abstractmethod
-    def get_diff(self, other) -> Optional[list[str]]:
+    def get_diff(self, other: object) -> Optional[list[str]]:
         """
         Returns a list of strings showing the difference between this and some
         other object
 
         Args:
-            other (Any): object to compare
+            other (object): object to compare
 
         Returns:
             Optional[list[str]]: difference
